@@ -1,7 +1,7 @@
 """ vapory/__init__.py """
 
 
-from vapory import *
+from .vapory import *
 from .version import __version__
 
  
@@ -10,4 +10,4 @@ __all__ = [k for k in locals().keys() if k not in
             'deepcopy',
             'wikiref',
             'vectorize',
-            'format_if_necessary']]
\ No newline at end of file
+            'format_if_necessary']]
